@@ -1,4 +1,4 @@
-from TMotorCANControl.CAN_Manager import *
+from TMotorCANControl.CAN_Manager_mit import *
 import can
 import time
 import csv
@@ -86,7 +86,6 @@ class TMotorManager_mit_can():
         self._updated = False
         self.use_torque_compensation = use_torque_compensation
         self.SF = 1.0
-        self.extra_plots = []
         
         self.log_vars = log_vars
         self.LOG_FUNCTIONS = {
@@ -268,7 +267,7 @@ class TMotorManager_mit_can():
 
         # writing to log file
         if self.csv_file_name is not None:
-            self.csv_writer.writerow([self._last_update_time - self._start_time] + [self.LOG_FUNCTIONS[var]() for var in self.log_vars] + self._times_past_current_limit +[data for data in self.extra_plots])
+            self.csv_writer.writerow([self._last_update_time - self._start_time] + [self.LOG_FUNCTIONS[var]() for var in self.log_vars])
 
         self._updated = False
     
@@ -308,7 +307,7 @@ class TMotorManager_mit_can():
 
     # zeros the position, like a scale you have to wait about a second before you can
     # use the motor again. This responsibility is on the user!!
-    def zero_position(self):
+    def set_zero_position(self):
         """Zeros the position--like a scale you have to wait about a second before you can
         use the motor again. This responsibility is on the user!!"""
         self._canman.zero(self.ID)
@@ -616,47 +615,41 @@ class TMotorManager_mit_can():
         self._canman.notifier.remove_listener(Listener)
         return success
 
-    ## Greek letter math symbol property interface. This is the good
-    #  interface, for those who like code that resembles math. It works best
-    #  to use the UnicodeMath plugin for sublime-text, "Fast Unicode Math
-    #  Characters" in VS Code, or the like to allow easy typing of ϕ, θ, and
-    #  τ.
-
     # controller variables
-    T = property(get_temperature_celsius, doc="temperature_degrees_C")
+    temperature = property(get_temperature_celsius, doc="temperature_degrees_C")
     """Temperature in Degrees Celsius"""
 
-    e = property(get_motor_error_code, doc="temperature_degrees_C")
+    error = property(get_motor_error_code, doc="temperature_degrees_C")
     """Motor error code. 0 means no error."""
 
     # electrical variables
-    i = property(get_current_qaxis_amps, set_motor_current_qaxis_amps, doc="current_qaxis_amps_current_only")
+    current_qaxis = property(get_current_qaxis_amps, set_motor_current_qaxis_amps, doc="current_qaxis_amps_current_only")
     """Q-axis current in amps"""
 
     # output-side variables
-    θ = property(get_output_angle_radians, set_output_angle_radians, doc="output_angle_radians_impedance_only")
+    position = property(get_output_angle_radians, set_output_angle_radians, doc="output_angle_radians_impedance_only")
     """Output angle in rad"""
 
-    θd = property (get_output_velocity_radians_per_second, set_output_velocity_radians_per_second, doc="output_velocity_radians_per_second")
+    velocity = property (get_output_velocity_radians_per_second, set_output_velocity_radians_per_second, doc="output_velocity_radians_per_second")
     """Output velocity in rad/s"""
 
-    θdd = property(get_output_acceleration_radians_per_second_squared, doc="output_acceleration_radians_per_second_squared")
+    acceleration = property(get_output_acceleration_radians_per_second_squared, doc="output_acceleration_radians_per_second_squared")
     """Output acceleration in rad/s/s"""
 
-    τ = property(get_output_torque_newton_meters, set_output_torque_newton_meters, doc="output_torque_newton_meters")
+    torque = property(get_output_torque_newton_meters, set_output_torque_newton_meters, doc="output_torque_newton_meters")
     """Output torque in Nm"""
 
     # motor-side variables
-    ϕ = property(get_motor_angle_radians, set_motor_angle_radians, doc="motor_angle_radians_impedance_only")
+    position_motorside = property(get_motor_angle_radians, set_motor_angle_radians, doc="motor_angle_radians_impedance_only")
     """Motor-side angle in rad"""
     
-    ϕd = property (get_motor_velocity_radians_per_second, set_motor_velocity_radians_per_second, doc="motor_velocity_radians_per_second")
+    velocity_motorside = property (get_motor_velocity_radians_per_second, set_motor_velocity_radians_per_second, doc="motor_velocity_radians_per_second")
     """Motor-side velocity in rad/s"""
 
-    ϕdd = property(get_motor_acceleration_radians_per_second_squared, doc="motor_acceleration_radians_per_second_squared")
+    acceleration_motorside = property(get_motor_acceleration_radians_per_second_squared, doc="motor_acceleration_radians_per_second_squared")
     """Motor-side acceleration in rad/s/s"""
 
-    τm = property(get_motor_torque_newton_meters, set_motor_torque_newton_meters, doc="motor_torque_newton_meters")
+    torque_motorside = property(get_motor_torque_newton_meters, set_motor_torque_newton_meters, doc="motor_torque_newton_meters")
     """Motor-side torque in Nm"""
 
 
